from_base64

Function from_base64 

pub fn from_base64(dst: &mut [u8], src: &[u8]) -> Result<(usize, usize), Error>
from_base64(dst, dst_len, src).

Decodes until the first non-base64 byte. Returns (bytes_written, bytes_consumed), where bytes_consumed indexes the first non-base64 byte in src — the equivalent of the pointer the C returns. The end of the slice acts as the C’s terminating NUL, which is itself not a base64 character.

Errors

Error::DecodingFail if dst is too small, if acc_len > 4 at the end, or if any buffered low bits are non-zero.